# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _port_info_list
else:
    import _port_info_list

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _port_info_list.SWIG_PyInstanceMethod_New
_swig_new_static_method = _port_info_list.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.abilities_list
import gphoto2.camera
import gphoto2.context
import gphoto2.file
import gphoto2.filesys
import gphoto2.list
import gphoto2.port_log
import gphoto2.result
import gphoto2.version
import gphoto2.widget
class _GPPortInfo(object):
    r"""Proxy of C _GPPortInfo struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    get_name = _swig_new_instance_method(_port_info_list._GPPortInfo_get_name)
    get_path = _swig_new_instance_method(_port_info_list._GPPortInfo_get_path)
    get_type = _swig_new_instance_method(_port_info_list._GPPortInfo_get_type)
    __swig_destroy__ = _port_info_list.delete__GPPortInfo

# Register _GPPortInfo in _port_info_list:
_port_info_list._GPPortInfo_swigregister(_GPPortInfo)

class PortInfoList(object):
    r"""Proxy of C _GPPortInfoList struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __len__ = _swig_new_instance_method(_port_info_list.PortInfoList___len__)
    __getitem__ = _swig_new_instance_method(_port_info_list.PortInfoList___getitem__)
    append = _swig_new_instance_method(_port_info_list.PortInfoList_append)
    load = _swig_new_instance_method(_port_info_list.PortInfoList_load)
    count = _swig_new_instance_method(_port_info_list.PortInfoList_count)
    lookup_path = _swig_new_instance_method(_port_info_list.PortInfoList_lookup_path)
    lookup_name = _swig_new_instance_method(_port_info_list.PortInfoList_lookup_name)
    get_info = _swig_new_instance_method(_port_info_list.PortInfoList_get_info)

    def __init__(self):
        r"""__init__(self) -> PortInfoList"""
        _port_info_list.PortInfoList_swiginit(self, _port_info_list.new_PortInfoList())
    __swig_destroy__ = _port_info_list.delete_PortInfoList

# Register PortInfoList in _port_info_list:
_port_info_list.PortInfoList_swigregister(PortInfoList)

GP_PORT_NONE = _port_info_list.GP_PORT_NONE

GP_PORT_SERIAL = _port_info_list.GP_PORT_SERIAL

GP_PORT_USB = _port_info_list.GP_PORT_USB

GP_PORT_DISK = _port_info_list.GP_PORT_DISK

GP_PORT_PTPIP = _port_info_list.GP_PORT_PTPIP

GP_PORT_USB_DISK_DIRECT = _port_info_list.GP_PORT_USB_DISK_DIRECT

GP_PORT_USB_SCSI = _port_info_list.GP_PORT_USB_SCSI

GP_PORT_IP = _port_info_list.GP_PORT_IP

gp_port_info_get_name = _port_info_list.gp_port_info_get_name
gp_port_info_get_path = _port_info_list.gp_port_info_get_path
gp_port_info_get_type = _port_info_list.gp_port_info_get_type
gp_port_info_list_new = _port_info_list.gp_port_info_list_new
gp_port_info_list_append = _port_info_list.gp_port_info_list_append
gp_port_info_list_load = _port_info_list.gp_port_info_list_load
gp_port_info_list_count = _port_info_list.gp_port_info_list_count
gp_port_info_list_lookup_path = _port_info_list.gp_port_info_list_lookup_path
gp_port_info_list_lookup_name = _port_info_list.gp_port_info_list_lookup_name
gp_port_info_list_get_info = _port_info_list.gp_port_info_list_get_info
gp_port_message_codeset = _port_info_list.gp_port_message_codeset





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _file
else:
    import _file

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _file.SWIG_PyInstanceMethod_New
_swig_new_static_method = _file.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.abilities_list
import gphoto2.camera
import gphoto2.context
import gphoto2.filesys
import gphoto2.list
import gphoto2.port_info_list
import gphoto2.port_log
import gphoto2.result
import gphoto2.version
import gphoto2.widget
gp_file_open = _file.gp_file_open
class CameraFile(object):
    r"""The internals of the CameraFile struct are private."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    set_name = _swig_new_instance_method(_file.CameraFile_set_name)
    get_name = _swig_new_instance_method(_file.CameraFile_get_name)
    set_mime_type = _swig_new_instance_method(_file.CameraFile_set_mime_type)
    get_mime_type = _swig_new_instance_method(_file.CameraFile_get_mime_type)
    set_mtime = _swig_new_instance_method(_file.CameraFile_set_mtime)
    get_mtime = _swig_new_instance_method(_file.CameraFile_get_mtime)
    detect_mime_type = _swig_new_instance_method(_file.CameraFile_detect_mime_type)
    adjust_name_for_mime_type = _swig_new_instance_method(_file.CameraFile_adjust_name_for_mime_type)
    get_name_by_type = _swig_new_instance_method(_file.CameraFile_get_name_by_type)
    set_data_and_size = _swig_new_instance_method(_file.CameraFile_set_data_and_size)
    get_data_and_size = _swig_new_instance_method(_file.CameraFile_get_data_and_size)
    save = _swig_new_instance_method(_file.CameraFile_save)
    clean = _swig_new_instance_method(_file.CameraFile_clean)
    copy = _swig_new_instance_method(_file.CameraFile_copy)
    append = _swig_new_instance_method(_file.CameraFile_append)

    def __init__(self):
        r"""
        __init__(self) -> CameraFile
        The internals of the CameraFile struct are private.
        """
        _file.CameraFile_swiginit(self, _file.new_CameraFile())
    __swig_destroy__ = _file.delete_CameraFile

# Register CameraFile in _file:
_file.CameraFile_swigregister(CameraFile)

GP_MIME_TXT = _file.GP_MIME_TXT

GP_MIME_WAV = _file.GP_MIME_WAV

GP_MIME_RAW = _file.GP_MIME_RAW

GP_MIME_PNG = _file.GP_MIME_PNG

GP_MIME_PGM = _file.GP_MIME_PGM

GP_MIME_PPM = _file.GP_MIME_PPM

GP_MIME_PNM = _file.GP_MIME_PNM

GP_MIME_JPEG = _file.GP_MIME_JPEG

GP_MIME_TIFF = _file.GP_MIME_TIFF

GP_MIME_BMP = _file.GP_MIME_BMP

GP_MIME_QUICKTIME = _file.GP_MIME_QUICKTIME

GP_MIME_AVI = _file.GP_MIME_AVI

GP_MIME_CRW = _file.GP_MIME_CRW

GP_MIME_CR2 = _file.GP_MIME_CR2

GP_MIME_CR3 = _file.GP_MIME_CR3

GP_MIME_NEF = _file.GP_MIME_NEF

GP_MIME_UNKNOWN = _file.GP_MIME_UNKNOWN

GP_MIME_EXIF = _file.GP_MIME_EXIF

GP_MIME_MP3 = _file.GP_MIME_MP3

GP_MIME_OGG = _file.GP_MIME_OGG

GP_MIME_WMA = _file.GP_MIME_WMA

GP_MIME_ASF = _file.GP_MIME_ASF

GP_MIME_MPEG = _file.GP_MIME_MPEG

GP_MIME_AVCHD = _file.GP_MIME_AVCHD

GP_MIME_RW2 = _file.GP_MIME_RW2

GP_MIME_ARW = _file.GP_MIME_ARW

GP_FILE_TYPE_PREVIEW = _file.GP_FILE_TYPE_PREVIEW

GP_FILE_TYPE_NORMAL = _file.GP_FILE_TYPE_NORMAL

GP_FILE_TYPE_RAW = _file.GP_FILE_TYPE_RAW

GP_FILE_TYPE_AUDIO = _file.GP_FILE_TYPE_AUDIO

GP_FILE_TYPE_EXIF = _file.GP_FILE_TYPE_EXIF

GP_FILE_TYPE_METADATA = _file.GP_FILE_TYPE_METADATA

GP_FILE_ACCESSTYPE_MEMORY = _file.GP_FILE_ACCESSTYPE_MEMORY

GP_FILE_ACCESSTYPE_FD = _file.GP_FILE_ACCESSTYPE_FD

GP_FILE_ACCESSTYPE_HANDLER = _file.GP_FILE_ACCESSTYPE_HANDLER

gp_file_new = _file.gp_file_new
gp_file_new_from_fd = _file.gp_file_new_from_fd
gp_file_new_from_handler = _file.gp_file_new_from_handler
gp_file_set_name = _file.gp_file_set_name
gp_file_get_name = _file.gp_file_get_name
gp_file_set_mime_type = _file.gp_file_set_mime_type
gp_file_get_mime_type = _file.gp_file_get_mime_type
gp_file_set_mtime = _file.gp_file_set_mtime
gp_file_get_mtime = _file.gp_file_get_mtime
gp_file_detect_mime_type = _file.gp_file_detect_mime_type
gp_file_adjust_name_for_mime_type = _file.gp_file_adjust_name_for_mime_type
gp_file_get_name_by_type = _file.gp_file_get_name_by_type
gp_file_set_data_and_size = _file.gp_file_set_data_and_size
gp_file_get_data_and_size = _file.gp_file_get_data_and_size
gp_file_save = _file.gp_file_save
gp_file_clean = _file.gp_file_clean
gp_file_copy = _file.gp_file_copy
gp_file_append = _file.gp_file_append





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _abilities_list
else:
    import _abilities_list

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _abilities_list.SWIG_PyInstanceMethod_New
_swig_new_static_method = _abilities_list.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.camera
import gphoto2.context
import gphoto2.file
import gphoto2.filesys
import gphoto2.list
import gphoto2.port_info_list
import gphoto2.port_log
import gphoto2.result
import gphoto2.version
import gphoto2.widget
class CameraAbilitiesList(object):
    r"""Proxy of C _CameraAbilitiesList struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        r"""__init__(self) -> CameraAbilitiesList"""
        _abilities_list.CameraAbilitiesList_swiginit(self, _abilities_list.new_CameraAbilitiesList())
    __swig_destroy__ = _abilities_list.delete_CameraAbilitiesList
    __len__ = _swig_new_instance_method(_abilities_list.CameraAbilitiesList___len__)
    __getitem__ = _swig_new_instance_method(_abilities_list.CameraAbilitiesList___getitem__)
    load = _swig_new_instance_method(_abilities_list.CameraAbilitiesList_load)
    load_dir = _swig_new_instance_method(_abilities_list.CameraAbilitiesList_load_dir)
    reset = _swig_new_instance_method(_abilities_list.CameraAbilitiesList_reset)
    detect = _swig_new_instance_method(_abilities_list.CameraAbilitiesList_detect)
    append = _swig_new_instance_method(_abilities_list.CameraAbilitiesList_append)
    count = _swig_new_instance_method(_abilities_list.CameraAbilitiesList_count)
    lookup_model = _swig_new_instance_method(_abilities_list.CameraAbilitiesList_lookup_model)
    get_abilities = _swig_new_instance_method(_abilities_list.CameraAbilitiesList_get_abilities)

# Register CameraAbilitiesList in _abilities_list:
_abilities_list.CameraAbilitiesList_swigregister(CameraAbilitiesList)

GP_DRIVER_STATUS_PRODUCTION = _abilities_list.GP_DRIVER_STATUS_PRODUCTION

GP_DRIVER_STATUS_TESTING = _abilities_list.GP_DRIVER_STATUS_TESTING

GP_DRIVER_STATUS_EXPERIMENTAL = _abilities_list.GP_DRIVER_STATUS_EXPERIMENTAL

GP_DRIVER_STATUS_DEPRECATED = _abilities_list.GP_DRIVER_STATUS_DEPRECATED

GP_DEVICE_STILL_CAMERA = _abilities_list.GP_DEVICE_STILL_CAMERA

GP_DEVICE_AUDIO_PLAYER = _abilities_list.GP_DEVICE_AUDIO_PLAYER

GP_OPERATION_NONE = _abilities_list.GP_OPERATION_NONE

GP_OPERATION_CAPTURE_IMAGE = _abilities_list.GP_OPERATION_CAPTURE_IMAGE

GP_OPERATION_CAPTURE_VIDEO = _abilities_list.GP_OPERATION_CAPTURE_VIDEO

GP_OPERATION_CAPTURE_AUDIO = _abilities_list.GP_OPERATION_CAPTURE_AUDIO

GP_OPERATION_CAPTURE_PREVIEW = _abilities_list.GP_OPERATION_CAPTURE_PREVIEW

GP_OPERATION_CONFIG = _abilities_list.GP_OPERATION_CONFIG

GP_OPERATION_TRIGGER_CAPTURE = _abilities_list.GP_OPERATION_TRIGGER_CAPTURE

GP_FILE_OPERATION_NONE = _abilities_list.GP_FILE_OPERATION_NONE

GP_FILE_OPERATION_DELETE = _abilities_list.GP_FILE_OPERATION_DELETE

GP_FILE_OPERATION_PREVIEW = _abilities_list.GP_FILE_OPERATION_PREVIEW

GP_FILE_OPERATION_RAW = _abilities_list.GP_FILE_OPERATION_RAW

GP_FILE_OPERATION_AUDIO = _abilities_list.GP_FILE_OPERATION_AUDIO

GP_FILE_OPERATION_EXIF = _abilities_list.GP_FILE_OPERATION_EXIF

GP_FOLDER_OPERATION_NONE = _abilities_list.GP_FOLDER_OPERATION_NONE

GP_FOLDER_OPERATION_DELETE_ALL = _abilities_list.GP_FOLDER_OPERATION_DELETE_ALL

GP_FOLDER_OPERATION_PUT_FILE = _abilities_list.GP_FOLDER_OPERATION_PUT_FILE

GP_FOLDER_OPERATION_MAKE_DIR = _abilities_list.GP_FOLDER_OPERATION_MAKE_DIR

GP_FOLDER_OPERATION_REMOVE_DIR = _abilities_list.GP_FOLDER_OPERATION_REMOVE_DIR

class CameraAbilities(object):
    r"""
    Describes the properties of a specific camera.  

    The internals of this structures are used extensively by the camlibs,
    but the status regarding use by frontends is questionable.  

    C++ includes: gphoto2-abilities-list.h
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    model = property(_abilities_list.CameraAbilities_model_get, doc=r"""model""")
    status = property(_abilities_list.CameraAbilities_status_get, doc=r"""status""")
    port = property(_abilities_list.CameraAbilities_port_get, doc=r"""port""")
    speed = property(_abilities_list.CameraAbilities_speed_get, doc=r"""speed""")
    operations = property(_abilities_list.CameraAbilities_operations_get, doc=r"""operations""")
    file_operations = property(_abilities_list.CameraAbilities_file_operations_get, doc=r"""file_operations""")
    folder_operations = property(_abilities_list.CameraAbilities_folder_operations_get, doc=r"""folder_operations""")
    usb_vendor = property(_abilities_list.CameraAbilities_usb_vendor_get, doc=r"""usb_vendor""")
    usb_product = property(_abilities_list.CameraAbilities_usb_product_get, doc=r"""usb_product""")
    usb_class = property(_abilities_list.CameraAbilities_usb_class_get, doc=r"""usb_class""")
    usb_subclass = property(_abilities_list.CameraAbilities_usb_subclass_get, doc=r"""usb_subclass""")
    usb_protocol = property(_abilities_list.CameraAbilities_usb_protocol_get, doc=r"""usb_protocol""")
    library = property(_abilities_list.CameraAbilities_library_get, doc=r"""library""")
    id = property(_abilities_list.CameraAbilities_id_get, doc=r"""id""")
    device_type = property(_abilities_list.CameraAbilities_device_type_get, doc=r"""device_type""")
    reserved2 = property(_abilities_list.CameraAbilities_reserved2_get, doc=r"""reserved2""")
    reserved3 = property(_abilities_list.CameraAbilities_reserved3_get, doc=r"""reserved3""")
    reserved4 = property(_abilities_list.CameraAbilities_reserved4_get, doc=r"""reserved4""")
    reserved5 = property(_abilities_list.CameraAbilities_reserved5_get, doc=r"""reserved5""")
    reserved6 = property(_abilities_list.CameraAbilities_reserved6_get, doc=r"""reserved6""")
    reserved7 = property(_abilities_list.CameraAbilities_reserved7_get, doc=r"""reserved7""")
    reserved8 = property(_abilities_list.CameraAbilities_reserved8_get, doc=r"""reserved8""")
    __swig_destroy__ = _abilities_list.delete_CameraAbilities

# Register CameraAbilities in _abilities_list:
_abilities_list.CameraAbilities_swigregister(CameraAbilities)

gp_abilities_list_new = _abilities_list.gp_abilities_list_new
gp_abilities_list_load = _abilities_list.gp_abilities_list_load
gp_abilities_list_load_dir = _abilities_list.gp_abilities_list_load_dir
gp_abilities_list_reset = _abilities_list.gp_abilities_list_reset
gp_abilities_list_detect = _abilities_list.gp_abilities_list_detect
gp_abilities_list_append = _abilities_list.gp_abilities_list_append
gp_abilities_list_count = _abilities_list.gp_abilities_list_count
gp_abilities_list_lookup_model = _abilities_list.gp_abilities_list_lookup_model
gp_abilities_list_get_abilities = _abilities_list.gp_abilities_list_get_abilities
gp_message_codeset = _abilities_list.gp_message_codeset





#!/usr/bin/env python

# python-gphoto2 - Python interface to libgphoto2
# http://github.com/jim-easterbrook/python-gphoto2
# Copyright (C) 2014-20  Jim Easterbrook  jim@jim-easterbrook.me.uk
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# "object oriented" version of camera-summary.py

from __future__ import print_function

import logging
import six
import sys

import gphoto2 as gp

def main():
    logging.basicConfig(
        format='%(levelname)s: %(name)s: %(message)s', level=logging.WARNING)
    callback_obj = gp.check_result(gp.use_python_logging())
    # make a list of all available cameras
    camera_list = list(gp.Camera.autodetect())
    if not camera_list:
        print('No camera detected')
        return 1
    camera_list.sort(key=lambda x: x[0])
    # ask user to choose one
    for index, (name, addr) in enumerate(camera_list):
        print('{:d}:  {:s}  {:s}'.format(index, addr, name))
    if six.PY3:
        choice = input('Please input number of chosen camera: ')
    else:
        choice = raw_input('Please input number of chosen camera: ')
    try:
        choice = int(choice)
    except ValueError:
        print('Integer values only!')
        return 2
    if choice < 0 or choice >= len(camera_list):
        print('Number out of range')
        return 3
    # initialise chosen camera
    name, addr = camera_list[choice]
    camera = gp.Camera()
    # search ports for camera port name
    port_info_list = gp.PortInfoList()
    port_info_list.load()
    idx = port_info_list.lookup_path(addr)
    camera.set_port_info(port_info_list[idx])
    camera.init()
    text = camera.get_summary()
    print('Summary')
    print('=======')
    print(str(text))
    try:
        text = camera.get_manual()
        print('Manual')
        print('=======')
        print(str(text))
    except Exception as ex:
        print(str(ex))
    camera.exit()
    return 0

if __name__ == "__main__":
    sys.exit(main())



#!/usr/bin/env python

# python-gphoto2 - Python interface to libgphoto2
# http://github.com/jim-easterbrook/python-gphoto2
# Copyright (C) 2017  Jim Easterbrook  jim@jim-easterbrook.me.uk
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import difflib
import os
import sys
import time

def main():
    if len(sys.argv) != 3:
        print('Two arguments required')
        return 1
    root_1 = os.path.join('src', 'swig-bi-py3-gp' + sys.argv[1])
    root_2 = os.path.join('src', 'swig-bi-py3-gp' + sys.argv[2])
    print('Comparing {} and {}'.format(root_1, root_2))
    for root, dirs, files in os.walk(root_1):
        for name in files:
            this = os.path.join(root, name)
            that = os.path.join(root.replace(root_1, root_2), name)
            if not os.path.exists(that):
                print('File {} does not exist'.format(that))
            else:
                this_date = time.ctime(os.stat(this).st_mtime)
                that_date = time.ctime(os.stat(that).st_mtime)
                diff = difflib.unified_diff(
                    open(this).readlines(), open(that).readlines(),
                    this, that, this_date, that_date, n=4)
                sys.stdout.writelines(diff)
    for root, dirs, files in os.walk(root_2):
        for name in files:
            that = os.path.join(root.replace(root_1, root_2), name)
            if not os.path.exists(that):
                print('File {} does not exist'.format(that))
    return 0

if __name__ == '__main__':
    sys.exit(main())



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _camera
else:
    import _camera

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _camera.SWIG_PyInstanceMethod_New
_swig_new_static_method = _camera.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.abilities_list
import gphoto2.context
import gphoto2.file
import gphoto2.filesys
import gphoto2.list
import gphoto2.port_info_list
import gphoto2.port_log
import gphoto2.result
import gphoto2.version
import gphoto2.widget
gp_camera_capture_preview = _camera.gp_camera_capture_preview
class CameraText(object):
    r"""
    CameraText structure used in various functions.  

    A text structure containing translated text returned by various
    functions (about, manual, summary). You should not assume a size.  

    C++ includes: gphoto2-camera.h
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    __str__ = _swig_new_instance_method(_camera.CameraText___str__)
    text = property(_camera.CameraText_text_get, doc=r"""text""")
    __swig_destroy__ = _camera.delete_CameraText

# Register CameraText in _camera:
_camera.CameraText_swigregister(CameraText)

class CameraFilePath(object):
    r"""
    A structure created by the capture operation.  

    A structure containing the folder and filename of an object after a
    successful capture and is passed as reference to the gp_camera_capture()
    function.  

    C++ includes: gphoto2-camera.h
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    name = property(_camera.CameraFilePath_name_get, doc=r"""name""")
    folder = property(_camera.CameraFilePath_folder_get, doc=r"""folder""")
    __swig_destroy__ = _camera.delete_CameraFilePath

# Register CameraFilePath in _camera:
_camera.CameraFilePath_swigregister(CameraFilePath)

GP_CAPTURE_IMAGE = _camera.GP_CAPTURE_IMAGE

GP_CAPTURE_MOVIE = _camera.GP_CAPTURE_MOVIE

GP_CAPTURE_SOUND = _camera.GP_CAPTURE_SOUND

GP_EVENT_UNKNOWN = _camera.GP_EVENT_UNKNOWN

GP_EVENT_TIMEOUT = _camera.GP_EVENT_TIMEOUT

GP_EVENT_FILE_ADDED = _camera.GP_EVENT_FILE_ADDED

GP_EVENT_FOLDER_ADDED = _camera.GP_EVENT_FOLDER_ADDED

GP_EVENT_CAPTURE_COMPLETE = _camera.GP_EVENT_CAPTURE_COMPLETE

GP_EVENT_FILE_CHANGED = _camera.GP_EVENT_FILE_CHANGED

class Camera(object):
    r"""Proxy of C _Camera struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        r"""__init__(self) -> Camera"""
        _camera.Camera_swiginit(self, _camera.new_Camera())
    __swig_destroy__ = _camera.delete_Camera
    autodetect = _swig_new_static_method(_camera.Camera_autodetect)
    set_abilities = _swig_new_instance_method(_camera.Camera_set_abilities)
    get_abilities = _swig_new_instance_method(_camera.Camera_get_abilities)
    set_port_info = _swig_new_instance_method(_camera.Camera_set_port_info)
    get_port_info = _swig_new_instance_method(_camera.Camera_get_port_info)
    set_port_speed = _swig_new_instance_method(_camera.Camera_set_port_speed)
    get_port_speed = _swig_new_instance_method(_camera.Camera_get_port_speed)
    init = _swig_new_instance_method(_camera.Camera_init)
    exit = _swig_new_instance_method(_camera.Camera_exit)
    get_config = _swig_new_instance_method(_camera.Camera_get_config)
    list_config = _swig_new_instance_method(_camera.Camera_list_config)
    get_single_config = _swig_new_instance_method(_camera.Camera_get_single_config)
    set_config = _swig_new_instance_method(_camera.Camera_set_config)
    set_single_config = _swig_new_instance_method(_camera.Camera_set_single_config)
    get_summary = _swig_new_instance_method(_camera.Camera_get_summary)
    get_manual = _swig_new_instance_method(_camera.Camera_get_manual)
    get_about = _swig_new_instance_method(_camera.Camera_get_about)
    capture = _swig_new_instance_method(_camera.Camera_capture)
    trigger_capture = _swig_new_instance_method(_camera.Camera_trigger_capture)
    capture_preview = _swig_new_instance_method(_camera.Camera_capture_preview)
    wait_for_event = _swig_new_instance_method(_camera.Camera_wait_for_event)
    get_storageinfo = _swig_new_instance_method(_camera.Camera_get_storageinfo)
    folder_list_files = _swig_new_instance_method(_camera.Camera_folder_list_files)
    folder_list_folders = _swig_new_instance_method(_camera.Camera_folder_list_folders)
    folder_delete_all = _swig_new_instance_method(_camera.Camera_folder_delete_all)
    folder_put_file = _swig_new_instance_method(_camera.Camera_folder_put_file)
    folder_make_dir = _swig_new_instance_method(_camera.Camera_folder_make_dir)
    folder_remove_dir = _swig_new_instance_method(_camera.Camera_folder_remove_dir)
    file_get_info = _swig_new_instance_method(_camera.Camera_file_get_info)
    file_set_info = _swig_new_instance_method(_camera.Camera_file_set_info)
    file_get = _swig_new_instance_method(_camera.Camera_file_get)
    file_read = _swig_new_instance_method(_camera.Camera_file_read)
    file_delete = _swig_new_instance_method(_camera.Camera_file_delete)

# Register Camera in _camera:
_camera.Camera_swigregister(Camera)
Camera_autodetect = _camera.Camera_autodetect

gp_camera_new = _camera.gp_camera_new
gp_camera_set_abilities = _camera.gp_camera_set_abilities
gp_camera_get_abilities = _camera.gp_camera_get_abilities
gp_camera_set_port_info = _camera.gp_camera_set_port_info
gp_camera_get_port_info = _camera.gp_camera_get_port_info
gp_camera_set_port_speed = _camera.gp_camera_set_port_speed
gp_camera_get_port_speed = _camera.gp_camera_get_port_speed
gp_camera_autodetect = _camera.gp_camera_autodetect
gp_camera_init = _camera.gp_camera_init
gp_camera_exit = _camera.gp_camera_exit
gp_camera_get_config = _camera.gp_camera_get_config
gp_camera_list_config = _camera.gp_camera_list_config
gp_camera_get_single_config = _camera.gp_camera_get_single_config
gp_camera_set_config = _camera.gp_camera_set_config
gp_camera_set_single_config = _camera.gp_camera_set_single_config
gp_camera_get_summary = _camera.gp_camera_get_summary
gp_camera_get_manual = _camera.gp_camera_get_manual
gp_camera_get_about = _camera.gp_camera_get_about
gp_camera_capture = _camera.gp_camera_capture
gp_camera_trigger_capture = _camera.gp_camera_trigger_capture
gp_camera_wait_for_event = _camera.gp_camera_wait_for_event
gp_camera_get_storageinfo = _camera.gp_camera_get_storageinfo
gp_camera_folder_list_files = _camera.gp_camera_folder_list_files
gp_camera_folder_list_folders = _camera.gp_camera_folder_list_folders
gp_camera_folder_delete_all = _camera.gp_camera_folder_delete_all
gp_camera_folder_put_file = _camera.gp_camera_folder_put_file
gp_camera_folder_make_dir = _camera.gp_camera_folder_make_dir
gp_camera_folder_remove_dir = _camera.gp_camera_folder_remove_dir
gp_camera_file_get_info = _camera.gp_camera_file_get_info
gp_camera_file_set_info = _camera.gp_camera_file_set_info
gp_camera_file_get = _camera.gp_camera_file_get
gp_camera_file_read = _camera.gp_camera_file_read
gp_camera_file_delete = _camera.gp_camera_file_delete
gp_camera_set_timeout_funcs = _camera.gp_camera_set_timeout_funcs
gp_camera_start_timeout = _camera.gp_camera_start_timeout
gp_camera_stop_timeout = _camera.gp_camera_stop_timeout





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _context
else:
    import _context

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _context.SWIG_PyInstanceMethod_New
_swig_new_static_method = _context.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.abilities_list
import gphoto2.camera
import gphoto2.file
import gphoto2.filesys
import gphoto2.list
import gphoto2.port_info_list
import gphoto2.port_log
import gphoto2.result
import gphoto2.version
import gphoto2.widget
class CallbackDetails(object):
    r"""Proxy of C CallbackDetails struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    func_1 = property(_context.CallbackDetails_func_1_get, _context.CallbackDetails_func_1_set, doc=r"""func_1""")
    func_2 = property(_context.CallbackDetails_func_2_get, _context.CallbackDetails_func_2_set, doc=r"""func_2""")
    func_3 = property(_context.CallbackDetails_func_3_get, _context.CallbackDetails_func_3_set, doc=r"""func_3""")
    __swig_destroy__ = _context.delete_CallbackDetails

# Register CallbackDetails in _context:
_context.CallbackDetails_swigregister(CallbackDetails)

unset_progress_funcs = _context.unset_progress_funcs
class Context(object):
    r"""Proxy of C _GPContext struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    camera_autodetect = _swig_new_instance_method(_context.Context_camera_autodetect)
    set_idle_func = _swig_new_instance_method(_context.Context_set_idle_func)
    set_error_func = _swig_new_instance_method(_context.Context_set_error_func)
    set_message_func = _swig_new_instance_method(_context.Context_set_message_func)
    set_question_func = _swig_new_instance_method(_context.Context_set_question_func)
    set_cancel_func = _swig_new_instance_method(_context.Context_set_cancel_func)
    set_progress_funcs = _swig_new_instance_method(_context.Context_set_progress_funcs)
    set_status_func = _swig_new_instance_method(_context.Context_set_status_func)

    def __init__(self):
        r"""__init__(self) -> Context"""
        _context.Context_swiginit(self, _context.new_Context())
    __swig_destroy__ = _context.delete_Context

# Register Context in _context:
_context.Context_swigregister(Context)

gp_context_new = _context.gp_context_new
GP_CONTEXT_FEEDBACK_OK = _context.GP_CONTEXT_FEEDBACK_OK

GP_CONTEXT_FEEDBACK_CANCEL = _context.GP_CONTEXT_FEEDBACK_CANCEL

gp_context_set_idle_func = _context.gp_context_set_idle_func
gp_context_set_progress_funcs = _context.gp_context_set_progress_funcs
gp_context_set_error_func = _context.gp_context_set_error_func
gp_context_set_status_func = _context.gp_context_set_status_func
gp_context_set_question_func = _context.gp_context_set_question_func
gp_context_set_cancel_func = _context.gp_context_set_cancel_func
gp_context_set_message_func = _context.gp_context_set_message_func





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _filesys
else:
    import _filesys

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _filesys.SWIG_PyInstanceMethod_New
_swig_new_static_method = _filesys.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.abilities_list
import gphoto2.camera
import gphoto2.context
import gphoto2.file
import gphoto2.list
import gphoto2.port_info_list
import gphoto2.port_log
import gphoto2.result
import gphoto2.version
import gphoto2.widget
class _CameraFilesystem(object):
    r"""
    The internal camera filesystem structure.  

    The internals of the CameraFilesystem are only visible to gphoto2. You
    can only access them using the functions provided by gphoto2.
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        r"""
        __init__(self) -> _CameraFilesystem
        The internal camera filesystem structure.  

        The internals of the CameraFilesystem are only visible to gphoto2. You
        can only access them using the functions provided by gphoto2.
        """
        _filesys._CameraFilesystem_swiginit(self, _filesys.new__CameraFilesystem())
    __swig_destroy__ = _filesys.delete__CameraFilesystem

# Register _CameraFilesystem in _filesys:
_filesys._CameraFilesystem_swigregister(_CameraFilesystem)

GP_FILE_INFO_NONE = _filesys.GP_FILE_INFO_NONE

GP_FILE_INFO_TYPE = _filesys.GP_FILE_INFO_TYPE

GP_FILE_INFO_SIZE = _filesys.GP_FILE_INFO_SIZE

GP_FILE_INFO_WIDTH = _filesys.GP_FILE_INFO_WIDTH

GP_FILE_INFO_HEIGHT = _filesys.GP_FILE_INFO_HEIGHT

GP_FILE_INFO_PERMISSIONS = _filesys.GP_FILE_INFO_PERMISSIONS

GP_FILE_INFO_STATUS = _filesys.GP_FILE_INFO_STATUS

GP_FILE_INFO_MTIME = _filesys.GP_FILE_INFO_MTIME

GP_FILE_INFO_ALL = _filesys.GP_FILE_INFO_ALL

GP_FILE_PERM_NONE = _filesys.GP_FILE_PERM_NONE

GP_FILE_PERM_READ = _filesys.GP_FILE_PERM_READ

GP_FILE_PERM_DELETE = _filesys.GP_FILE_PERM_DELETE

GP_FILE_PERM_ALL = _filesys.GP_FILE_PERM_ALL

GP_FILE_STATUS_NOT_DOWNLOADED = _filesys.GP_FILE_STATUS_NOT_DOWNLOADED

GP_FILE_STATUS_DOWNLOADED = _filesys.GP_FILE_STATUS_DOWNLOADED

class CameraFileInfoFile(object):
    r"""
    File information of a regular file.  

    Contains information a regular file with fields being set depending on
    the bitmask in the fields member.  

    C++ includes: gphoto2-filesys.h
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    fields = property(_filesys.CameraFileInfoFile_fields_get, doc=r"""fields""")
    status = property(_filesys.CameraFileInfoFile_status_get, doc=r"""status""")
    size = property(_filesys.CameraFileInfoFile_size_get, doc=r"""size""")
    type = property(_filesys.CameraFileInfoFile_type_get, doc=r"""type""")
    width = property(_filesys.CameraFileInfoFile_width_get, doc=r"""width""")
    height = property(_filesys.CameraFileInfoFile_height_get, doc=r"""height""")
    permissions = property(_filesys.CameraFileInfoFile_permissions_get, doc=r"""permissions""")
    mtime = property(_filesys.CameraFileInfoFile_mtime_get, doc=r"""mtime""")
    __swig_destroy__ = _filesys.delete_CameraFileInfoFile

# Register CameraFileInfoFile in _filesys:
_filesys.CameraFileInfoFile_swigregister(CameraFileInfoFile)

class CameraFileInfoPreview(object):
    r"""
    File information of a preview file.  

    Contains information of a preview file with fields being set depending
    on the bitmask in the fields member.  

    C++ includes: gphoto2-filesys.h
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    fields = property(_filesys.CameraFileInfoPreview_fields_get, doc=r"""fields""")
    status = property(_filesys.CameraFileInfoPreview_status_get, doc=r"""status""")
    size = property(_filesys.CameraFileInfoPreview_size_get, doc=r"""size""")
    type = property(_filesys.CameraFileInfoPreview_type_get, doc=r"""type""")
    width = property(_filesys.CameraFileInfoPreview_width_get, doc=r"""width""")
    height = property(_filesys.CameraFileInfoPreview_height_get, doc=r"""height""")
    __swig_destroy__ = _filesys.delete_CameraFileInfoPreview

# Register CameraFileInfoPreview in _filesys:
_filesys.CameraFileInfoPreview_swigregister(CameraFileInfoPreview)

class CameraFileInfoAudio(object):
    r"""
    File information of an audio file.  

    Contains information of an audio file with fields being set depending on
    the bitmask in the fields member.  

    C++ includes: gphoto2-filesys.h
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    fields = property(_filesys.CameraFileInfoAudio_fields_get, doc=r"""fields""")
    status = property(_filesys.CameraFileInfoAudio_status_get, doc=r"""status""")
    size = property(_filesys.CameraFileInfoAudio_size_get, doc=r"""size""")
    type = property(_filesys.CameraFileInfoAudio_type_get, doc=r"""type""")
    __swig_destroy__ = _filesys.delete_CameraFileInfoAudio

# Register CameraFileInfoAudio in _filesys:
_filesys.CameraFileInfoAudio_swigregister(CameraFileInfoAudio)

class CameraFileInfo(object):
    r"""
    File information structure.  

    Contains the normal, preview and audio file information structures for a
    specific file.  

    C++ includes: gphoto2-filesys.h
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    preview = property(_filesys.CameraFileInfo_preview_get, doc=r"""preview""")
    file = property(_filesys.CameraFileInfo_file_get, doc=r"""file""")
    audio = property(_filesys.CameraFileInfo_audio_get, doc=r"""audio""")
    __swig_destroy__ = _filesys.delete_CameraFileInfo

# Register CameraFileInfo in _filesys:
_filesys.CameraFileInfo_swigregister(CameraFileInfo)

GP_STORAGEINFO_BASE = _filesys.GP_STORAGEINFO_BASE

GP_STORAGEINFO_LABEL = _filesys.GP_STORAGEINFO_LABEL

GP_STORAGEINFO_DESCRIPTION = _filesys.GP_STORAGEINFO_DESCRIPTION

GP_STORAGEINFO_ACCESS = _filesys.GP_STORAGEINFO_ACCESS

GP_STORAGEINFO_STORAGETYPE = _filesys.GP_STORAGEINFO_STORAGETYPE

GP_STORAGEINFO_FILESYSTEMTYPE = _filesys.GP_STORAGEINFO_FILESYSTEMTYPE

GP_STORAGEINFO_MAXCAPACITY = _filesys.GP_STORAGEINFO_MAXCAPACITY

GP_STORAGEINFO_FREESPACEKBYTES = _filesys.GP_STORAGEINFO_FREESPACEKBYTES

GP_STORAGEINFO_FREESPACEIMAGES = _filesys.GP_STORAGEINFO_FREESPACEIMAGES

GP_STORAGEINFO_ST_UNKNOWN = _filesys.GP_STORAGEINFO_ST_UNKNOWN

GP_STORAGEINFO_ST_FIXED_ROM = _filesys.GP_STORAGEINFO_ST_FIXED_ROM

GP_STORAGEINFO_ST_REMOVABLE_ROM = _filesys.GP_STORAGEINFO_ST_REMOVABLE_ROM

GP_STORAGEINFO_ST_FIXED_RAM = _filesys.GP_STORAGEINFO_ST_FIXED_RAM

GP_STORAGEINFO_ST_REMOVABLE_RAM = _filesys.GP_STORAGEINFO_ST_REMOVABLE_RAM

GP_STORAGEINFO_AC_READWRITE = _filesys.GP_STORAGEINFO_AC_READWRITE

GP_STORAGEINFO_AC_READONLY = _filesys.GP_STORAGEINFO_AC_READONLY

GP_STORAGEINFO_AC_READONLY_WITH_DELETE = _filesys.GP_STORAGEINFO_AC_READONLY_WITH_DELETE

GP_STORAGEINFO_FST_UNDEFINED = _filesys.GP_STORAGEINFO_FST_UNDEFINED

GP_STORAGEINFO_FST_GENERICFLAT = _filesys.GP_STORAGEINFO_FST_GENERICFLAT

GP_STORAGEINFO_FST_GENERICHIERARCHICAL = _filesys.GP_STORAGEINFO_FST_GENERICHIERARCHICAL

GP_STORAGEINFO_FST_DCF = _filesys.GP_STORAGEINFO_FST_DCF

class CameraStorageInformation(object):
    r"""
    Storage information structue.  

    This structure contains the information of a specific camera storage.
    Only the members as specified by the *fields* member are valid.  

    C++ includes: gphoto2-filesys.h
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    fields = property(_filesys.CameraStorageInformation_fields_get, doc=r"""fields""")
    basedir = property(_filesys.CameraStorageInformation_basedir_get, doc=r"""basedir""")
    label = property(_filesys.CameraStorageInformation_label_get, doc=r"""label""")
    description = property(_filesys.CameraStorageInformation_description_get, doc=r"""description""")
    type = property(_filesys.CameraStorageInformation_type_get, doc=r"""type""")
    fstype = property(_filesys.CameraStorageInformation_fstype_get, doc=r"""fstype""")
    access = property(_filesys.CameraStorageInformation_access_get, doc=r"""access""")
    capacitykbytes = property(_filesys.CameraStorageInformation_capacitykbytes_get, doc=r"""capacitykbytes""")
    freekbytes = property(_filesys.CameraStorageInformation_freekbytes_get, doc=r"""freekbytes""")
    freeimages = property(_filesys.CameraStorageInformation_freeimages_get, doc=r"""freeimages""")
    __swig_destroy__ = _filesys.delete_CameraStorageInformation

# Register CameraStorageInformation in _filesys:
_filesys.CameraStorageInformation_swigregister(CameraStorageInformation)

gp_filesystem_new = _filesys.gp_filesystem_new
gp_filesystem_append = _filesys.gp_filesystem_append
gp_filesystem_set_info_noop = _filesys.gp_filesystem_set_info_noop
gp_filesystem_set_file_noop = _filesys.gp_filesystem_set_file_noop
gp_filesystem_delete_file_noop = _filesys.gp_filesystem_delete_file_noop
gp_filesystem_reset = _filesys.gp_filesystem_reset
gp_filesystem_count = _filesys.gp_filesystem_count
gp_filesystem_name = _filesys.gp_filesystem_name
gp_filesystem_get_folder = _filesys.gp_filesystem_get_folder
gp_filesystem_number = _filesys.gp_filesystem_number
gp_filesystem_list_files = _filesys.gp_filesystem_list_files
gp_filesystem_list_folders = _filesys.gp_filesystem_list_folders
gp_filesystem_get_info = _filesys.gp_filesystem_get_info
gp_filesystem_set_info = _filesys.gp_filesystem_set_info
gp_filesystem_get_file = _filesys.gp_filesystem_get_file
gp_filesystem_read_file = _filesys.gp_filesystem_read_file
gp_filesystem_delete_file = _filesys.gp_filesystem_delete_file
class _CameraFilesystemFuncs(object):
    r"""Proxy of C _CameraFilesystemFuncs struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    file_list_func = property(_filesys._CameraFilesystemFuncs_file_list_func_get, doc=r"""
    file_list_func
    List available files in the specified folder.  

    This function is a CameraFilesystem method.
    """)
    folder_list_func = property(_filesys._CameraFilesystemFuncs_folder_list_func_get, doc=r"""
    folder_list_func
    List available folders in the specified folder.  

    This function is a CameraFilesystem method.
    """)
    put_file_func = property(_filesys._CameraFilesystemFuncs_put_file_func_get, doc=r"""
    put_file_func
    Put a file onto the camera.  

    This function is a CameraFilesystem method.
    """)
    delete_all_func = property(_filesys._CameraFilesystemFuncs_delete_all_func_get, doc=r"""
    delete_all_func
    Delete all files from the camera.  

    This function is a CameraFilesystem method.
    """)
    get_info_func = property(_filesys._CameraFilesystemFuncs_get_info_func_get, doc=r"""
    get_info_func
    Get the file info here and write it to space provided by caller.  

    Parameters
    ----------
    * `info` :  
        Space provided by caller in which file info is written.  

    This function is a CameraFilesystem method.
    """)
    set_info_func = property(_filesys._CameraFilesystemFuncs_set_info_func_get, doc=r"""
    set_info_func
    FIXME.  

    This function is a CameraFilesystem method.
    """)
    make_dir_func = property(_filesys._CameraFilesystemFuncs_make_dir_func_get, doc=r"""make_dir_func""")
    remove_dir_func = property(_filesys._CameraFilesystemFuncs_remove_dir_func_get, doc=r"""remove_dir_func""")
    get_file_func = property(_filesys._CameraFilesystemFuncs_get_file_func_get, doc=r"""
    get_file_func
    Get the file from the camera.  

    This function is a CameraFilesystem method.
    """)
    read_file_func = property(_filesys._CameraFilesystemFuncs_read_file_func_get, doc=r"""read_file_func""")
    del_file_func = property(_filesys._CameraFilesystemFuncs_del_file_func_get, doc=r"""del_file_func""")
    storage_info_func = property(_filesys._CameraFilesystemFuncs_storage_info_func_get, doc=r"""
    storage_info_func
    Get information on all available storages in the camera.  

    This function is a CameraFilesystem method.
    """)
    unused = property(_filesys._CameraFilesystemFuncs_unused_get, doc=r"""unused""")
    __swig_destroy__ = _filesys.delete__CameraFilesystemFuncs

# Register _CameraFilesystemFuncs in _filesys:
_filesys._CameraFilesystemFuncs_swigregister(_CameraFilesystemFuncs)

gp_filesystem_set_funcs = _filesys.gp_filesystem_set_funcs
gp_filesystem_put_file = _filesys.gp_filesystem_put_file
gp_filesystem_delete_all = _filesys.gp_filesystem_delete_all
gp_filesystem_make_dir = _filesys.gp_filesystem_make_dir
gp_filesystem_remove_dir = _filesys.gp_filesystem_remove_dir
gp_filesystem_dump = _filesys.gp_filesystem_dump





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _result
else:
    import _result

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _result.SWIG_PyInstanceMethod_New
_swig_new_static_method = _result.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.abilities_list
import gphoto2.camera
import gphoto2.context
import gphoto2.file
import gphoto2.filesys
import gphoto2.list
import gphoto2.port_info_list
import gphoto2.port_log
import gphoto2.version
import gphoto2.widget
GP_OK = _result.GP_OK

GP_ERROR = _result.GP_ERROR

GP_ERROR_BAD_PARAMETERS = _result.GP_ERROR_BAD_PARAMETERS

GP_ERROR_NO_MEMORY = _result.GP_ERROR_NO_MEMORY

GP_ERROR_LIBRARY = _result.GP_ERROR_LIBRARY

GP_ERROR_UNKNOWN_PORT = _result.GP_ERROR_UNKNOWN_PORT

GP_ERROR_NOT_SUPPORTED = _result.GP_ERROR_NOT_SUPPORTED

GP_ERROR_IO = _result.GP_ERROR_IO

GP_ERROR_FIXED_LIMIT_EXCEEDED = _result.GP_ERROR_FIXED_LIMIT_EXCEEDED

GP_ERROR_TIMEOUT = _result.GP_ERROR_TIMEOUT

GP_ERROR_IO_SUPPORTED_SERIAL = _result.GP_ERROR_IO_SUPPORTED_SERIAL

GP_ERROR_IO_SUPPORTED_USB = _result.GP_ERROR_IO_SUPPORTED_USB

GP_ERROR_IO_INIT = _result.GP_ERROR_IO_INIT

GP_ERROR_IO_READ = _result.GP_ERROR_IO_READ

GP_ERROR_IO_WRITE = _result.GP_ERROR_IO_WRITE

GP_ERROR_IO_UPDATE = _result.GP_ERROR_IO_UPDATE

GP_ERROR_IO_SERIAL_SPEED = _result.GP_ERROR_IO_SERIAL_SPEED

GP_ERROR_IO_USB_CLEAR_HALT = _result.GP_ERROR_IO_USB_CLEAR_HALT

GP_ERROR_IO_USB_FIND = _result.GP_ERROR_IO_USB_FIND

GP_ERROR_IO_USB_CLAIM = _result.GP_ERROR_IO_USB_CLAIM

GP_ERROR_IO_LOCK = _result.GP_ERROR_IO_LOCK

GP_ERROR_HAL = _result.GP_ERROR_HAL

gp_port_result_as_string = _result.gp_port_result_as_string
GP_ERROR_CORRUPTED_DATA = _result.GP_ERROR_CORRUPTED_DATA

GP_ERROR_FILE_EXISTS = _result.GP_ERROR_FILE_EXISTS

GP_ERROR_MODEL_NOT_FOUND = _result.GP_ERROR_MODEL_NOT_FOUND

GP_ERROR_DIRECTORY_NOT_FOUND = _result.GP_ERROR_DIRECTORY_NOT_FOUND

GP_ERROR_FILE_NOT_FOUND = _result.GP_ERROR_FILE_NOT_FOUND

GP_ERROR_DIRECTORY_EXISTS = _result.GP_ERROR_DIRECTORY_EXISTS

GP_ERROR_CAMERA_BUSY = _result.GP_ERROR_CAMERA_BUSY

GP_ERROR_PATH_NOT_ABSOLUTE = _result.GP_ERROR_PATH_NOT_ABSOLUTE

GP_ERROR_CANCEL = _result.GP_ERROR_CANCEL

GP_ERROR_CAMERA_ERROR = _result.GP_ERROR_CAMERA_ERROR

GP_ERROR_OS_FAILURE = _result.GP_ERROR_OS_FAILURE

GP_ERROR_NO_SPACE = _result.GP_ERROR_NO_SPACE

gp_result_as_string = _result.gp_result_as_string

import logging

# user adjustable check_result lookup table
error_severity = {
    GP_ERROR_CANCEL           : logging.INFO,
    GP_ERROR_DIRECTORY_EXISTS : logging.WARNING,
    }
error_exception = logging.ERROR

_return_logger = logging.getLogger('gphoto2.returnvalue')

def check_result(result):
    """Pops gphoto2 'error' value from 'result' list and checks it.

    If there is no error the remaining result is returned. For other
    errors a severity level is taken from the error_severity dict, or
    set to logging.CRITICAL if the error is not in error_severity.

    If the severity >= error_exception an exception is raised.
    Otherwise a message is logged at the appropriate severity level.
    """

    if not isinstance(result, (tuple, list)):
        error = result
    elif len(result) == 2:
        error, result = result
    else:
        error = result[0]
        result = result[1:]
    if error >= GP_OK:
        return result
    severity = logging.CRITICAL
    if error in error_severity:
        severity = error_severity[error]
    if severity >= error_exception:
        raise gphoto2.GPhoto2Error(error)
    _return_logger.log(severity, '[%d] %s', error, gp_result_as_string(error))
    return result






# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _list
else:
    import _list

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _list.SWIG_PyInstanceMethod_New
_swig_new_static_method = _list.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.abilities_list
import gphoto2.camera
import gphoto2.context
import gphoto2.file
import gphoto2.filesys
import gphoto2.port_info_list
import gphoto2.port_log
import gphoto2.result
import gphoto2.version
import gphoto2.widget
class CameraList(object):
    r"""Proxy of C _CameraList struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    __len__ = _swig_new_instance_method(_list.CameraList___len__)
    __getitem__ = _swig_new_instance_method(_list.CameraList___getitem__)
    count = _swig_new_instance_method(_list.CameraList_count)
    append = _swig_new_instance_method(_list.CameraList_append)
    reset = _swig_new_instance_method(_list.CameraList_reset)
    sort = _swig_new_instance_method(_list.CameraList_sort)
    find_by_name = _swig_new_instance_method(_list.CameraList_find_by_name)
    get_name = _swig_new_instance_method(_list.CameraList_get_name)
    get_value = _swig_new_instance_method(_list.CameraList_get_value)
    set_name = _swig_new_instance_method(_list.CameraList_set_name)
    set_value = _swig_new_instance_method(_list.CameraList_set_value)
    populate = _swig_new_instance_method(_list.CameraList_populate)

    def __init__(self):
        r"""__init__(self) -> CameraList"""
        _list.CameraList_swiginit(self, _list.new_CameraList())
    __swig_destroy__ = _list.delete_CameraList

# Register CameraList in _list:
_list.CameraList_swigregister(CameraList)

gp_list_new = _list.gp_list_new
gp_list_count = _list.gp_list_count
gp_list_append = _list.gp_list_append
gp_list_reset = _list.gp_list_reset
gp_list_sort = _list.gp_list_sort
gp_list_find_by_name = _list.gp_list_find_by_name
gp_list_get_name = _list.gp_list_get_name
gp_list_get_value = _list.gp_list_get_value
gp_list_set_name = _list.gp_list_set_name
gp_list_set_value = _list.gp_list_set_value
gp_list_populate = _list.gp_list_populate





#!/usr/bin/env python

# python-gphoto2 - Python interface to libgphoto2
# http://github.com/jim-easterbrook/python-gphoto2
# Copyright (C) 2018-19  Jim Easterbrook  jim@jim-easterbrook.me.uk
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Simple time lapse script.

This works OK with my Canon SLR, but will probably need changes to work
with another camera.

"""

from __future__ import print_function

from contextlib import contextmanager
import os
import subprocess
import sys
import time

import gphoto2 as gp


# time between captures
INTERVAL = 10.0
# temporary directory
WORK_DIR = '/tmp/time_lapse'
# result
OUT_FILE = 'time_lapse.mp4'


@contextmanager
def configured_camera():
    # initialise camera
    camera = gp.Camera()
    camera.init()
    try:
        # adjust camera configuratiuon
        cfg = camera.get_config()
        capturetarget_cfg = cfg.get_child_by_name('capturetarget')
        capturetarget = capturetarget_cfg.get_value()
        capturetarget_cfg.set_value('Internal RAM')
        # camera dependent - 'imageformat' is 'imagequality' on some
        imageformat_cfg = cfg.get_child_by_name('imageformat')
        imageformat = imageformat_cfg.get_value()
        imageformat_cfg.set_value('Small Fine JPEG')
        camera.set_config(cfg)
        # use camera
        yield camera
    finally:
        # reset configuration
        capturetarget_cfg.set_value(capturetarget)
        imageformat_cfg.set_value(imageformat)
        camera.set_config(cfg)
        # free camera
        camera.exit()


def empty_event_queue(camera):
    while True:
        type_, data = camera.wait_for_event(10)
        if type_ == gp.GP_EVENT_TIMEOUT:
            return
        if type_ == gp.GP_EVENT_FILE_ADDED:
            # get a second image if camera is set to raw + jpeg
            print('Unexpected new file', data.folder + data.name)


def main():
    if not os.path.exists(WORK_DIR):
        os.makedirs(WORK_DIR)
    template = os.path.join(WORK_DIR, 'frame%04d.jpg')
    next_shot = time.time() + 1.0
    count = 0
    with configured_camera() as camera:
        while True:
            try:
                empty_event_queue(camera)
                while True:
                    sleep = next_shot - time.time()
                    if sleep < 0.0:
                        break
                    time.sleep(sleep)
                path = camera.capture(gp.GP_CAPTURE_IMAGE)
                print('capture', path.folder + path.name)
                camera_file = camera.file_get(
                    path.folder, path.name, gp.GP_FILE_TYPE_NORMAL)
                camera_file.save(template % count)
                camera.file_delete(path.folder, path.name)
                next_shot += INTERVAL
                count += 1
            except KeyboardInterrupt:
                break
    subprocess.check_call(['ffmpeg', '-r', '25',
                           '-i', template, '-c:v', 'h264', OUT_FILE])
    for i in range(count):
        os.unlink(template % i)
    return 0


if __name__ == "__main__":
    sys.exit(main())



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _widget
else:
    import _widget

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _widget.SWIG_PyInstanceMethod_New
_swig_new_static_method = _widget.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.abilities_list
import gphoto2.camera
import gphoto2.context
import gphoto2.file
import gphoto2.filesys
import gphoto2.list
import gphoto2.port_info_list
import gphoto2.port_log
import gphoto2.result
import gphoto2.version
gp_widget_set_value = _widget.gp_widget_set_value
gp_widget_get_value = _widget.gp_widget_get_value
class CameraWidgetChildIter(object):
    r"""Proxy of C CameraWidgetChildIter struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def __iter__(self):
        return self
    def next(self):
        return self.__next__()

    __next__ = _swig_new_instance_method(_widget.CameraWidgetChildIter___next__)
    __swig_destroy__ = _widget.delete_CameraWidgetChildIter

# Register CameraWidgetChildIter in _widget:
_widget.CameraWidgetChildIter_swigregister(CameraWidgetChildIter)

gp_widget_get_children = _widget.gp_widget_get_children
class CameraWidgetChoiceIter(object):
    r"""Proxy of C CameraWidgetChoiceIter struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def __iter__(self):
        return self
    def next(self):
        return self.__next__()

    __next__ = _swig_new_instance_method(_widget.CameraWidgetChoiceIter___next__)
    __swig_destroy__ = _widget.delete_CameraWidgetChoiceIter

# Register CameraWidgetChoiceIter in _widget:
_widget.CameraWidgetChoiceIter_swigregister(CameraWidgetChoiceIter)

gp_widget_get_choices = _widget.gp_widget_get_choices
class CameraWidget(object):
    r"""
    CameraWidget:  

    The internals of the CameraWidget are only visible to gphoto2. You can
    only access them using the functions provided by gphoto2.
    """

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    count_children = _swig_new_instance_method(_widget.CameraWidget_count_children)
    get_child = _swig_new_instance_method(_widget.CameraWidget_get_child)
    get_children = _swig_new_instance_method(_widget.CameraWidget_get_children)
    get_child_by_label = _swig_new_instance_method(_widget.CameraWidget_get_child_by_label)
    get_child_by_id = _swig_new_instance_method(_widget.CameraWidget_get_child_by_id)
    get_child_by_name = _swig_new_instance_method(_widget.CameraWidget_get_child_by_name)
    get_root = _swig_new_instance_method(_widget.CameraWidget_get_root)
    get_parent = _swig_new_instance_method(_widget.CameraWidget_get_parent)
    set_value = _swig_new_instance_method(_widget.CameraWidget_set_value)
    get_value = _swig_new_instance_method(_widget.CameraWidget_get_value)
    set_name = _swig_new_instance_method(_widget.CameraWidget_set_name)
    get_name = _swig_new_instance_method(_widget.CameraWidget_get_name)
    set_info = _swig_new_instance_method(_widget.CameraWidget_set_info)
    get_info = _swig_new_instance_method(_widget.CameraWidget_get_info)
    get_id = _swig_new_instance_method(_widget.CameraWidget_get_id)
    get_type = _swig_new_instance_method(_widget.CameraWidget_get_type)
    get_label = _swig_new_instance_method(_widget.CameraWidget_get_label)
    set_range = _swig_new_instance_method(_widget.CameraWidget_set_range)
    get_range = _swig_new_instance_method(_widget.CameraWidget_get_range)
    add_choice = _swig_new_instance_method(_widget.CameraWidget_add_choice)
    count_choices = _swig_new_instance_method(_widget.CameraWidget_count_choices)
    get_choices = _swig_new_instance_method(_widget.CameraWidget_get_choices)
    get_choice = _swig_new_instance_method(_widget.CameraWidget_get_choice)
    changed = _swig_new_instance_method(_widget.CameraWidget_changed)
    set_changed = _swig_new_instance_method(_widget.CameraWidget_set_changed)
    set_readonly = _swig_new_instance_method(_widget.CameraWidget_set_readonly)
    get_readonly = _swig_new_instance_method(_widget.CameraWidget_get_readonly)
    __swig_destroy__ = _widget.delete_CameraWidget

# Register CameraWidget in _widget:
_widget.CameraWidget_swigregister(CameraWidget)

GP_WIDGET_WINDOW = _widget.GP_WIDGET_WINDOW

GP_WIDGET_SECTION = _widget.GP_WIDGET_SECTION

GP_WIDGET_TEXT = _widget.GP_WIDGET_TEXT

GP_WIDGET_RANGE = _widget.GP_WIDGET_RANGE

GP_WIDGET_TOGGLE = _widget.GP_WIDGET_TOGGLE

GP_WIDGET_RADIO = _widget.GP_WIDGET_RADIO

GP_WIDGET_MENU = _widget.GP_WIDGET_MENU

GP_WIDGET_BUTTON = _widget.GP_WIDGET_BUTTON

GP_WIDGET_DATE = _widget.GP_WIDGET_DATE

gp_widget_append = _widget.gp_widget_append
gp_widget_prepend = _widget.gp_widget_prepend
gp_widget_count_children = _widget.gp_widget_count_children
gp_widget_get_child = _widget.gp_widget_get_child
gp_widget_get_child_by_label = _widget.gp_widget_get_child_by_label
gp_widget_get_child_by_id = _widget.gp_widget_get_child_by_id
gp_widget_get_child_by_name = _widget.gp_widget_get_child_by_name
gp_widget_get_root = _widget.gp_widget_get_root
gp_widget_get_parent = _widget.gp_widget_get_parent
gp_widget_set_name = _widget.gp_widget_set_name
gp_widget_get_name = _widget.gp_widget_get_name
gp_widget_set_info = _widget.gp_widget_set_info
gp_widget_get_info = _widget.gp_widget_get_info
gp_widget_get_id = _widget.gp_widget_get_id
gp_widget_get_type = _widget.gp_widget_get_type
gp_widget_get_label = _widget.gp_widget_get_label
gp_widget_set_range = _widget.gp_widget_set_range
gp_widget_get_range = _widget.gp_widget_get_range
gp_widget_add_choice = _widget.gp_widget_add_choice
gp_widget_count_choices = _widget.gp_widget_count_choices
gp_widget_get_choice = _widget.gp_widget_get_choice
gp_widget_changed = _widget.gp_widget_changed
gp_widget_set_changed = _widget.gp_widget_set_changed
gp_widget_set_readonly = _widget.gp_widget_set_readonly
gp_widget_get_readonly = _widget.gp_widget_get_readonly





# python-gphoto2 - Python interface to libgphoto2
# http://github.com/jim-easterbrook/python-gphoto2
# Copyright (C) 2014-20  Jim Easterbrook  jim@jim-easterbrook.me.uk
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from collections import defaultdict
from distutils.cmd import Command
from distutils.command.upload import upload as _upload
from distutils.core import setup, Extension
from distutils.log import error
import os
import re
import subprocess
import sys

# python-gphoto2 version
version = '2.2.4'

# get gphoto2 library config
cmd = ['pkg-config', '--modversion', 'libgphoto2']
FNULL = open(os.devnull, 'w')
try:
    gphoto2_version = subprocess.check_output(
        cmd, stderr=FNULL, universal_newlines=True).split('.')[:3]
    gphoto2_version = tuple(map(int, gphoto2_version))
except Exception:
    error('ERROR: command "%s" failed', ' '.join(cmd))
    raise
gphoto2_flags = defaultdict(list)
for flag in subprocess.check_output(
        ['pkg-config', '--cflags', '--libs', 'libgphoto2'],
        universal_newlines=True).split():
    gphoto2_flags[flag[:2]].append(flag)
gphoto2_include  = gphoto2_flags['-I']
gphoto2_libs     = gphoto2_flags['-l']
gphoto2_lib_dirs = gphoto2_flags['-L']
for n in range(len(gphoto2_include)):
    if gphoto2_include[n].endswith('/gphoto2'):
        gphoto2_include[n] = gphoto2_include[n][:-len('/gphoto2')]

# create extension modules list
ext_modules = []
info_file = os.path.join('src', 'info.txt')
if os.path.exists(info_file):
    with open(info_file) as src:
        code = compile(src.read(), info_file, 'exec')
        exec(code, globals(), locals())
else:
    swig_version = (0, 0, 0)
use_builtin = (swig_version != (2, 0, 11) and
               (swig_version >= (3, 0, 8) or sys.version_info < (3, 5)))
if 'PYTHON_GPHOTO2_BUILTIN' in os.environ:
    use_builtin = True
if 'PYTHON_GPHOTO2_NO_BUILTIN' in os.environ:
    use_builtin = False
mod_src_dir = 'swig'
if use_builtin:
    mod_src_dir += '-bi'
mod_src_dir += '-py' + str(sys.version_info[0])
mod_src_dir += '-gp' + '.'.join(map(str, gphoto2_version[:2]))
mod_src_dir = os.path.join('src', mod_src_dir)

extra_compile_args = [
    '-O3', '-Wno-unused-variable', '-Wno-unused-but-set-variable',
    '-Wno-unused-label', '-Wno-strict-prototypes',
    '-DGPHOTO2_VERSION=' + '0x{:02x}{:02x}{:02x}'.format(*gphoto2_version)]
if 'PYTHON_GPHOTO2_STRICT' in os.environ:
    extra_compile_args.append('-Werror')
libraries = [x.replace('-l', '') for x in gphoto2_libs]
library_dirs = [x.replace('-L', '') for x in gphoto2_lib_dirs]
include_dirs = [x.replace('-I', '') for x in gphoto2_include]
if os.path.isdir(mod_src_dir):
    for file_name in os.listdir(mod_src_dir):
        if file_name[-7:] != '_wrap.c':
            continue
        ext_name = file_name[:-7]
        ext_modules.append(Extension(
            '_' + ext_name,
            sources = [os.path.join(mod_src_dir, file_name)],
            libraries = libraries,
            library_dirs = library_dirs,
            runtime_library_dirs = library_dirs,
            include_dirs = include_dirs,
            extra_compile_args = extra_compile_args,
            ))

cmdclass = {}
command_options = {}

def get_gp_versions():
    # get gphoto2 versions to be swigged
    gp_versions = []
    for name in os.listdir('.'):
        match = re.match('libgphoto2-(.*)', name)
        if match:
            gp_versions.append(match.group(1))
    gp_versions.sort()
    if not gp_versions:
        gp_versions = ['.'.join(map(str, gphoto2_version[:2]))]
    return gp_versions

# add command to run doxygen and doxy2swig
member_methods = (
    ('gp_abilities_list_', '_CameraAbilitiesList', 'CameraAbilitiesList'),
    ('gp_camera_',         '_Camera',              'Camera'),
    ('gp_context_',        '_GPContext',           'Context'),
    ('gp_file_',           '_CameraFile',          'CameraFile'),
    ('gp_list_',           '_CameraList',          'CameraList'),
    ('gp_port_info_list_', '_GPPortInfoList',      'PortInfoList'),
    ('gp_port_info_',      '_GPPortInfo',          'PortInfo'),
    ('gp_widget_',         '_CameraWidget',        'CameraWidget'),
    )

def add_member_doc(symbol, value):
    for key, c_type, py_type in member_methods:
        if symbol.startswith(key):
            method = symbol.replace(key, '')
            if method == 'new':
                return ('%feature("docstring") {} "{}\n\n' +
                        'See also gphoto2.{}"\n\n').format(
                            symbol, value, py_type)
            return ('%feature("docstring") {} "{}\n\n' +
                    'See also gphoto2.{}.{}"\n\n' +
                    '%feature("docstring") {}::{} "{}\n\n' +
                    'See also gphoto2.{}"\n\n').format(
                        symbol, value, py_type, method,
                        c_type, method, value, symbol)
    return '%feature("docstring") {} "{}"\n\n'.format(symbol, value)

class build_doc(Command):
    description = 'run doxygen to generate documentation'
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        gp_versions = get_gp_versions()
        self.announce('making docs for gphoto2 versions %s' % str(gp_versions), 2)
        sys.path.append('doxy2swig')
        from doxy2swig import Doxy2SWIG
        for gp_version in gp_versions:
            src_dir = 'libgphoto2-' + gp_version
            os.chdir(src_dir)
            self.spawn(['doxygen', '../developer/Doxyfile'])
            os.chdir('..')
            index_file = os.path.join(src_dir, 'doc', 'xml', 'index.xml')
            self.announce('Doxy2SWIG ' + index_file, 2)
            p = Doxy2SWIG(index_file,
                          with_function_signature = False,
                          with_type_info = False,
                          with_constructor_list = False,
                          with_attribute_list = False,
                          with_overloaded_functions = False,
                          textwidth = 72,
                          quiet = True)
            p.generate()
            text = ''.join(p.pieces)
            with open(os.path.join('src', 'gphoto2', 'common',
                                   'doc-' + gp_version + '.i'), 'w') as of:
                for match in re.finditer('%feature\("docstring"\) (\w+) \"(.+?)\";',
                                         text, re.DOTALL):
                    symbol = match.group(1)
                    value = match.group(2).strip()
                    if not value:
                        continue
                    of.write(add_member_doc(symbol, value))

cmdclass['build_doc'] = build_doc

# add command to run SWIG
class build_swig(Command):
    description = 'run SWIG to regenerate interface files'
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        # get list of modules (Python) and extensions (SWIG)
        file_names = os.listdir(os.path.join('src', 'gphoto2'))
        file_names.sort()
        file_names = [os.path.splitext(x) for x in file_names]
        ext_names = [x[0] for x in file_names if x[1] == '.i']
        # get gphoto2 versions to be swigged
        gp_versions = get_gp_versions()
        self.announce('swigging gphoto2 versions %s' % str(gp_versions), 2)
        # do -builtin and not -builtin
        swig_bis = [False]
        cmd = ['swig', '-version']
        try:
            swig_version = str(subprocess.check_output(
                cmd, universal_newlines=True))
        except Exception:
            error('ERROR: command "%s" failed', ' '.join(cmd))
            raise
        for line in swig_version.split('\n'):
            if 'Version' in line:
                swig_version = tuple(map(int, line.split()[-1].split('.')))
                if swig_version != (2, 0, 11):
                    swig_bis.append(True)
                break
        for use_builtin in swig_bis:
            # make options list
            swig_opts = ['-python', '-nodefaultctor', '-O', '-Wextra', '-Werror']
            if use_builtin:
                swig_opts += ['-builtin', '-nofastunpack']
            # do each gphoto2 version
            for gp_version in gp_versions:
                doc_file = os.path.join(
                    'src', 'gphoto2', 'common', 'doc-' + gp_version + '.i')
                # do Python 2 and 3
                for py_version in 2, 3:
                    output_dir = os.path.join('src', 'swig')
                    if use_builtin:
                        output_dir += '-bi'
                    output_dir += '-py' + str(py_version)
                    output_dir += '-gp' + gp_version
                    self.mkpath(output_dir)
                    version_opts = ['-outdir', output_dir]
                    if os.path.isfile(doc_file):
                        version_opts.append(
                            '-DDOC_FILE=' + os.path.basename(doc_file))
                    inc_dir = 'libgphoto2-' + gp_version
                    if os.path.isdir(inc_dir):
                        version_opts.append('-I' + inc_dir)
                        version_opts.append(
                            '-I' + os.path.join(inc_dir, 'libgphoto2_port'))
                    else:
                        version_opts += gphoto2_include
                    if py_version >= 3:
                        version_opts.append('-py3')
                    # do each swig module
                    for ext_name in ext_names:
                        in_file = os.path.join('src', 'gphoto2', ext_name + '.i')
                        out_file = os.path.join(output_dir, ext_name + '_wrap.c')
                        self.spawn(['swig'] + swig_opts + version_opts +
                                   ['-o', out_file, in_file])
                    # create init module
                    init_file = os.path.join(output_dir, '__init__.py')
                    with open(init_file, 'w') as im:
                        im.write('__version__ = "{}"\n\n'.format(version))
                        im.write('''
class GPhoto2Error(Exception):
    """Exception raised by gphoto2 library errors

    Attributes:
        code   (int): the gphoto2 error code
        string (str): corresponding error message
    """
    def __init__(self, code):
        string = gp_result_as_string(code)
        Exception.__init__(self, '[%d] %s' % (code, string))
        self.code = code
        self.string = string

''')
                        for name in ext_names:
                            im.write('from gphoto2.{} import *\n'.format(name))
                        im.write('''
__all__ = dir()
''')
        # store SWIG version
        info_file = os.path.join('src', 'info.txt')
        with open(info_file, 'w') as info:
            info.write('swig_version = {}\n'.format(repr(swig_version)))

cmdclass['build_swig'] = build_swig

# modify upload class to add appropriate git tag
# requires GitPython - 'sudo pip install gitpython --pre'
try:
    import git
    class upload(_upload):
        def run(self):
            message = 'v' + version + '\n\n'
            with open('CHANGELOG.txt') as cl:
                while not cl.readline().startswith('Changes'):
                    pass
                while True:
                    line = cl.readline().strip()
                    if not line:
                        break
                    message += line + '\n'
            repo = git.Repo()
            tag = repo.create_tag('v' + version, message=message)
            remote = repo.remotes.origin
            remote.push(tags=True)
            return _upload.run(self)
    cmdclass['upload'] = upload
except ImportError:
    pass

# set options for building distributions
command_options['sdist'] = {
    'formats' : ('setup.py', 'gztar'),
    }

# list example scripts
examples = [os.path.join('examples', x)
            for x in os.listdir('examples') if os.path.splitext(x)[1] == '.py']

with open('README.rst') as ldf:
    long_description = ldf.read()

setup(name = 'gphoto2',
      version = version,
      description = 'Python interface to libgphoto2',
      long_description = long_description,
      author = 'Jim Easterbrook',
      author_email = 'jim@jim-easterbrook.me.uk',
      url = 'https://github.com/jim-easterbrook/python-gphoto2',
      classifiers = [
          'Development Status :: 5 - Production/Stable',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
          'Operating System :: MacOS',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: POSIX',
          'Operating System :: POSIX :: BSD :: FreeBSD',
          'Operating System :: POSIX :: BSD :: NetBSD',
          'Operating System :: POSIX :: Linux',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Topic :: Multimedia',
          'Topic :: Multimedia :: Graphics',
          'Topic :: Multimedia :: Graphics :: Capture',
          ],
      platforms = ['POSIX', 'MacOS'],
      license = 'GNU GPL',
      cmdclass = cmdclass,
      command_options = command_options,
      ext_package = 'gphoto2',
      ext_modules = ext_modules,
      packages = ['gphoto2'],
      package_dir = {'gphoto2' : mod_src_dir},
      data_files = [
          ('share/python-gphoto2/examples', examples),
          ('share/python-gphoto2', [
              'CHANGELOG.txt', 'LICENSE.txt', 'README.rst']),
          ],
      )



#!/usr/bin/env python

# python-gphoto2 - Python interface to libgphoto2
# http://github.com/jim-easterbrook/python-gphoto2
# Copyright (C) 2015-19  Jim Easterbrook  jim@jim-easterbrook.me.uk
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# read just enough of an image to decode the Exif data

from __future__ import print_function

from datetime import datetime
import io
import logging
import os
import sys

import exifread
import gphoto2 as gp

def list_files(camera, path='/'):
    result = []
    # get files
    for name, value in camera.folder_list_files(path):
        result.append(os.path.join(path, name))
    # read folders
    folders = []
    for name, value in camera.folder_list_folders(path):
        folders.append(name)
    # recurse over subfolders
    for name in folders:
        result.extend(list_files(camera, os.path.join(path, name)))
    return result

class PseudoFile(object):
    def __init__(self, camera, path):
        self._camera = camera
        self._folder, self._file_name = os.path.split(path)
        info = self._camera.file_get_info(
            self._folder, self._file_name)
        self._size = info.file.size
        self._ptr = 0
        self._buf = bytearray(16 * 1024)
        self._buf_ptr = 0
        self._buf_len = 0

    def read(self, size=None):
        if size is None or size < 0:
            size = self._size - self._ptr
        if (self._ptr < self._buf_ptr or
                self._ptr >= self._buf_ptr + self._buf_len):
            self._buf_ptr = self._ptr - (self._ptr % len(self._buf))
            self._buf_len = self._camera.file_read(
                self._folder, self._file_name, gp.GP_FILE_TYPE_NORMAL,
                self._buf_ptr, self._buf)
        offset = self._ptr - self._buf_ptr
        size = min(size, self._buf_len - offset)
        self._ptr += size
        return self._buf[offset:offset + size]

    def seek(self, offset, whence=0):
        if whence == 0:
            self._ptr = offset
        elif whence == 1:
            self._ptr += offset
        else:
            self._ptr = self._size - ptr

    def tell(self):
        return self._ptr

def get_file_exif(camera, path):
    pf = PseudoFile(camera, path)
    return exifread.process_file(pf)

def main():
    logging.basicConfig(
        format='%(levelname)s: %(name)s: %(message)s', level=logging.WARNING)
    callback_obj = gp.check_result(gp.use_python_logging())
    camera = gp.Camera()
    camera.init()
    files = list_files(camera)
    if not files:
        print('No files found')
        return 1
    print('File list')
    print('=========')
    for path in files[:10]:
        print(path)
    print('...')
    for path in files[-10:]:
        print(path)
    print()
    print('Exif data')
    print('=========')
    for path in files:
        if os.path.splitext(path)[1].lower() != '.jpg':
            continue
        exif = get_file_exif(camera, path)
        for key in ('EXIF DateTimeOriginal', 'EXIF LensModel', 'Image Copyright'):
            if key in exif:
                print(key, ':', exif[key])
        break
    print()
    camera.exit()
    return 0

if __name__ == "__main__":
    sys.exit(main())



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _port_log
else:
    import _port_log

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

_swig_new_instance_method = _port_log.SWIG_PyInstanceMethod_New
_swig_new_static_method = _port_log.SWIG_PyStaticMethod_New

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import gphoto2.abilities_list
import gphoto2.camera
import gphoto2.context
import gphoto2.file
import gphoto2.filesys
import gphoto2.list
import gphoto2.port_info_list
import gphoto2.result
import gphoto2.version
import gphoto2.widget
class LogFuncItem(object):
    r"""Proxy of C LogFuncItem struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    __swig_destroy__ = _port_log.delete_LogFuncItem

# Register LogFuncItem in _port_log:
_port_log.LogFuncItem_swigregister(LogFuncItem)


import logging
import sys

def _gphoto2_logger_cb(level, domain, msg, data):
    log_func, mapping = data
    if sys.version_info[0] >= 3:
# decode bytes to str
        if domain:
            domain = domain.decode(errors='replace')
        if msg:
            msg = msg.decode(errors='replace')
    if level in mapping:
        log_func(mapping[level], '(%s) %s', domain, msg)
    else:
        log_func(logging.ERROR, '%d (%s) %s', level, domain, msg)

def use_python_logging(mapping={}):
    """Install a callback to receive gphoto2 errors and forward them
    to Python's logging system.

    The return value is a tuple containing an error code and a Python object
    containing details of the callback. Deleting this object will uninstall
    the callback.

    Parameters
    ----------
    * `mapping` :
        a dictionary mapping any of the four gphoto2 logging severity
        levels to a Python logging level. Note that anything below Python
        DEBUG level will not be forwarded.

    Returns
    -------
    a tuple containing an id or error code and a callback reference object.

    """
    full_mapping = {
        GP_LOG_ERROR   : logging.WARNING,
        GP_LOG_VERBOSE : logging.INFO,
        GP_LOG_DEBUG   : logging.DEBUG,
        GP_LOG_DATA    : logging.DEBUG - 5,
        }
    full_mapping.update(mapping)
    log_func = logging.getLogger('gphoto2').log
    for level in (GP_LOG_DATA, GP_LOG_DEBUG, GP_LOG_VERBOSE, GP_LOG_ERROR):
        if full_mapping[level] >= logging.DEBUG:
            break
    return gp_log_add_func(level, _gphoto2_logger_cb, (log_func, full_mapping))

GP_LOG_ERROR = _port_log.GP_LOG_ERROR

GP_LOG_VERBOSE = _port_log.GP_LOG_VERBOSE

GP_LOG_DEBUG = _port_log.GP_LOG_DEBUG

GP_LOG_DATA = _port_log.GP_LOG_DATA

gp_log_add_func = _port_log.gp_log_add_func
gp_log = _port_log.gp_log


